# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetProviderIntegrationSetupResult',
    'AwaitableGetProviderIntegrationSetupResult',
    'get_provider_integration_setup',
    'get_provider_integration_setup_output',
]

@pulumi.output_type
class GetProviderIntegrationSetupResult:
    """
    A collection of values returned by getProviderIntegrationSetup.
    """
    def __init__(__self__, cloud=None, display_name=None, environment=None, id=None, status=None, usages=None):
        if cloud and not isinstance(cloud, str):
            raise TypeError("Expected argument 'cloud' to be a str")
        pulumi.set(__self__, "cloud", cloud)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if usages and not isinstance(usages, list):
            raise TypeError("Expected argument 'usages' to be a list")
        pulumi.set(__self__, "usages", usages)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> _builtins.str:
        """
        (Computed String) The cloud service provider. Values are `AZURE` and `GCP`.
        """
        return pulumi.get(self, "cloud")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        (Required String) The display name of the Provider Integration.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetProviderIntegrationSetupEnvironmentResult':
        """
        (Required Configuration Block) supports the following:
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        (Required String) The ID of the Environment that the Provider Integration belongs to, for example, `env-abc123`.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (Required String) The status of the Provider Integration. Values are `DRAFT` and `CREATED`.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def usages(self) -> Sequence[_builtins.str]:
        """
        (Required List of Strings) List of resource CRNs where this provider integration is being used.
        """
        return pulumi.get(self, "usages")


class AwaitableGetProviderIntegrationSetupResult(GetProviderIntegrationSetupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProviderIntegrationSetupResult(
            cloud=self.cloud,
            display_name=self.display_name,
            environment=self.environment,
            id=self.id,
            status=self.status,
            usages=self.usages)


def get_provider_integration_setup(display_name: Optional[_builtins.str] = None,
                                   environment: Optional[Union['GetProviderIntegrationSetupEnvironmentArgs', 'GetProviderIntegrationSetupEnvironmentArgsDict']] = None,
                                   id: Optional[_builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProviderIntegrationSetupResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `ProviderIntegrationSetup` describes a Cloud Service Provider (CSP) integration that allows Confluent Cloud to access resources in your cloud provider account.

    ## Example Usage

    ### Azure Provider Integration

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    azure = confluentcloud.get_provider_integration_setup(id="cspi-abc123",
        environment={
            "id": "env-xyz456",
        })
    pulumi.export("azureIntegrationStatus", azure.status)
    ```

    ### GCP Provider Integration

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    gcp = confluentcloud.get_provider_integration_setup(display_name="my-gcp-integration",
        environment={
            "id": "env-xyz456",
        })
    pulumi.export("gcpIntegrationId", gcp.id)
    ```

    ### Using with Authorization Resource

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_provider_integration_setup(id="cspi-abc123",
        environment={
            "id": "env-xyz456",
        })
    # Use the integration with authorization data source
    main_get_provider_integration_authorization = confluentcloud.get_provider_integration_authorization(id=main.id,
        environment={
            "id": "env-xyz456",
        })
    ```

    ## Getting Started

    The following end-to-end examples might help to get started with `ProviderIntegrationSetup` data source:
    * provider-integration-azure: Complete Azure Provider Integration setup
    * provider-integration-gcp: Complete GCP Provider Integration setup


    :param _builtins.str display_name: The display name of the Provider Integration. Exactly one of `id` or `display_name` must be specified.
    :param Union['GetProviderIntegrationSetupEnvironmentArgs', 'GetProviderIntegrationSetupEnvironmentArgsDict'] environment: (Required Configuration Block) supports the following:
    :param _builtins.str id: The ID of the Provider Integration, for example, `cspi-4xg0q`. Exactly one of `id` or `display_name` must be specified.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getProviderIntegrationSetup:getProviderIntegrationSetup', __args__, opts=opts, typ=GetProviderIntegrationSetupResult).value

    return AwaitableGetProviderIntegrationSetupResult(
        cloud=pulumi.get(__ret__, 'cloud'),
        display_name=pulumi.get(__ret__, 'display_name'),
        environment=pulumi.get(__ret__, 'environment'),
        id=pulumi.get(__ret__, 'id'),
        status=pulumi.get(__ret__, 'status'),
        usages=pulumi.get(__ret__, 'usages'))
def get_provider_integration_setup_output(display_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          environment: Optional[pulumi.Input[Union['GetProviderIntegrationSetupEnvironmentArgs', 'GetProviderIntegrationSetupEnvironmentArgsDict']]] = None,
                                          id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProviderIntegrationSetupResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `ProviderIntegrationSetup` describes a Cloud Service Provider (CSP) integration that allows Confluent Cloud to access resources in your cloud provider account.

    ## Example Usage

    ### Azure Provider Integration

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    azure = confluentcloud.get_provider_integration_setup(id="cspi-abc123",
        environment={
            "id": "env-xyz456",
        })
    pulumi.export("azureIntegrationStatus", azure.status)
    ```

    ### GCP Provider Integration

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    gcp = confluentcloud.get_provider_integration_setup(display_name="my-gcp-integration",
        environment={
            "id": "env-xyz456",
        })
    pulumi.export("gcpIntegrationId", gcp.id)
    ```

    ### Using with Authorization Resource

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_provider_integration_setup(id="cspi-abc123",
        environment={
            "id": "env-xyz456",
        })
    # Use the integration with authorization data source
    main_get_provider_integration_authorization = confluentcloud.get_provider_integration_authorization(id=main.id,
        environment={
            "id": "env-xyz456",
        })
    ```

    ## Getting Started

    The following end-to-end examples might help to get started with `ProviderIntegrationSetup` data source:
    * provider-integration-azure: Complete Azure Provider Integration setup
    * provider-integration-gcp: Complete GCP Provider Integration setup


    :param _builtins.str display_name: The display name of the Provider Integration. Exactly one of `id` or `display_name` must be specified.
    :param Union['GetProviderIntegrationSetupEnvironmentArgs', 'GetProviderIntegrationSetupEnvironmentArgsDict'] environment: (Required Configuration Block) supports the following:
    :param _builtins.str id: The ID of the Provider Integration, for example, `cspi-4xg0q`. Exactly one of `id` or `display_name` must be specified.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['environment'] = environment
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getProviderIntegrationSetup:getProviderIntegrationSetup', __args__, opts=opts, typ=GetProviderIntegrationSetupResult)
    return __ret__.apply(lambda __response__: GetProviderIntegrationSetupResult(
        cloud=pulumi.get(__response__, 'cloud'),
        display_name=pulumi.get(__response__, 'display_name'),
        environment=pulumi.get(__response__, 'environment'),
        id=pulumi.get(__response__, 'id'),
        status=pulumi.get(__response__, 'status'),
        usages=pulumi.get(__response__, 'usages')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEndpointResult',
    'AwaitableGetEndpointResult',
    'get_endpoint',
    'get_endpoint_output',
]

@pulumi.output_type
class GetEndpointResult:
    """
    A collection of values returned by getEndpoint.
    """
    def __init__(__self__, endpoints=None, filter=None, id=None):
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if filter and not isinstance(filter, dict):
            raise TypeError("Expected argument 'filter' to be a dict")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetEndpointEndpointResult']:
        """
        (Computed List) List of endpoints matching the filter criteria. Each endpoint object contains:
        """
        return pulumi.get(self, "endpoints")

    @_builtins.property
    @pulumi.getter
    def filter(self) -> 'outputs.GetEndpointFilterResult':
        return pulumi.get(self, "filter")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetEndpointResult(GetEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointResult(
            endpoints=self.endpoints,
            filter=self.filter,
            id=self.id)


def get_endpoint(filter: Optional[Union['GetEndpointFilterArgs', 'GetEndpointFilterArgsDict']] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_endpoint` describes an Endpoint data source.

    An Endpoint object represents a Fully Qualified Domain Name (FQDN) for a Confluent service resource via a specific networking solution for a given Confluent Cloud environment. Endpoints can be filtered by service, cloud provider, region, etc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_endpoint(filter={
        "environment": {
            "id": "env-123abc",
        },
        "service": "KAFKA",
        "resource": "lkc-abc123",
        "cloud": "AWS",
        "region": "us-west-2",
    })
    pulumi.export("endpoints", main.endpoints)
    ```
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult).value

    return AwaitableGetEndpointResult(
        endpoints=pulumi.get(__ret__, 'endpoints'),
        filter=pulumi.get(__ret__, 'filter'),
        id=pulumi.get(__ret__, 'id'))
def get_endpoint_output(filter: Optional[pulumi.Input[Union['GetEndpointFilterArgs', 'GetEndpointFilterArgsDict']]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_endpoint` describes an Endpoint data source.

    An Endpoint object represents a Fully Qualified Domain Name (FQDN) for a Confluent service resource via a specific networking solution for a given Confluent Cloud environment. Endpoints can be filtered by service, cloud provider, region, etc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    main = confluentcloud.get_endpoint(filter={
        "environment": {
            "id": "env-123abc",
        },
        "service": "KAFKA",
        "resource": "lkc-abc123",
        "cloud": "AWS",
        "region": "us-west-2",
    })
    pulumi.export("endpoints", main.endpoints)
    ```
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult)
    return __ret__.apply(lambda __response__: GetEndpointResult(
        endpoints=pulumi.get(__response__, 'endpoints'),
        filter=pulumi.get(__response__, 'filter'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCatalogIntegrationResult',
    'AwaitableGetCatalogIntegrationResult',
    'get_catalog_integration',
    'get_catalog_integration_output',
]

@pulumi.output_type
class GetCatalogIntegrationResult:
    """
    A collection of values returned by getCatalogIntegration.
    """
    def __init__(__self__, aws_glues=None, credentials=None, display_name=None, environment=None, id=None, kafka_cluster=None, snowflakes=None, suspended=None):
        if aws_glues and not isinstance(aws_glues, list):
            raise TypeError("Expected argument 'aws_glues' to be a list")
        pulumi.set(__self__, "aws_glues", aws_glues)
        if credentials and not isinstance(credentials, dict):
            raise TypeError("Expected argument 'credentials' to be a dict")
        pulumi.set(__self__, "credentials", credentials)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kafka_cluster and not isinstance(kafka_cluster, dict):
            raise TypeError("Expected argument 'kafka_cluster' to be a dict")
        pulumi.set(__self__, "kafka_cluster", kafka_cluster)
        if snowflakes and not isinstance(snowflakes, list):
            raise TypeError("Expected argument 'snowflakes' to be a list")
        pulumi.set(__self__, "snowflakes", snowflakes)
        if suspended and not isinstance(suspended, bool):
            raise TypeError("Expected argument 'suspended' to be a bool")
        pulumi.set(__self__, "suspended", suspended)

    @_builtins.property
    @pulumi.getter(name="awsGlues")
    def aws_glues(self) -> Sequence['outputs.GetCatalogIntegrationAwsGlueResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "aws_glues")

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Optional['outputs.GetCatalogIntegrationCredentialsResult']:
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        (Required String) The name of the catalog integration.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetCatalogIntegrationEnvironmentResult':
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="kafkaCluster")
    def kafka_cluster(self) -> 'outputs.GetCatalogIntegrationKafkaClusterResult':
        return pulumi.get(self, "kafka_cluster")

    @_builtins.property
    @pulumi.getter
    def snowflakes(self) -> Sequence['outputs.GetCatalogIntegrationSnowflakeResult']:
        """
        (Optional Configuration Block) supports the following:
        """
        return pulumi.get(self, "snowflakes")

    @_builtins.property
    @pulumi.getter
    def suspended(self) -> _builtins.bool:
        """
        (Optional Boolean) Indicates whether the Catalog Integration should be suspended.
        """
        return pulumi.get(self, "suspended")


class AwaitableGetCatalogIntegrationResult(GetCatalogIntegrationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCatalogIntegrationResult(
            aws_glues=self.aws_glues,
            credentials=self.credentials,
            display_name=self.display_name,
            environment=self.environment,
            id=self.id,
            kafka_cluster=self.kafka_cluster,
            snowflakes=self.snowflakes,
            suspended=self.suspended)


def get_catalog_integration(credentials: Optional[Union['GetCatalogIntegrationCredentialsArgs', 'GetCatalogIntegrationCredentialsArgsDict']] = None,
                            environment: Optional[Union['GetCatalogIntegrationEnvironmentArgs', 'GetCatalogIntegrationEnvironmentArgsDict']] = None,
                            id: Optional[_builtins.str] = None,
                            kafka_cluster: Optional[Union['GetCatalogIntegrationKafkaClusterArgs', 'GetCatalogIntegrationKafkaClusterArgsDict']] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCatalogIntegrationResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `CatalogIntegration` describes a Catalog Integration data source.

    ## Example Usage

    ### Option #1: Manage multiple Catalog Integrations in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_catalog_integration(environment={
            "id": staging["id"],
        },
        kafka_cluster={
            "id": staging_confluent_kafka_cluster["id"],
        },
        id="tci-abc123",
        credentials={
            "key": env_admin_tableflow_api_key["id"],
            "secret": env_admin_tableflow_api_key["secret"],
        })
    pulumi.export("retention-ms", example.retention_ms)
    ```

    ### Option #2: Manage a single Catalog Integration in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_catalog_integration(id="tci-abc123")
    pulumi.export("retention-ms", example.retention_ms)
    ```


    :param _builtins.str id: The ID of the Catalog Integration, for example, `tci-abc123`.
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['environment'] = environment
    __args__['id'] = id
    __args__['kafkaCluster'] = kafka_cluster
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getCatalogIntegration:getCatalogIntegration', __args__, opts=opts, typ=GetCatalogIntegrationResult).value

    return AwaitableGetCatalogIntegrationResult(
        aws_glues=pulumi.get(__ret__, 'aws_glues'),
        credentials=pulumi.get(__ret__, 'credentials'),
        display_name=pulumi.get(__ret__, 'display_name'),
        environment=pulumi.get(__ret__, 'environment'),
        id=pulumi.get(__ret__, 'id'),
        kafka_cluster=pulumi.get(__ret__, 'kafka_cluster'),
        snowflakes=pulumi.get(__ret__, 'snowflakes'),
        suspended=pulumi.get(__ret__, 'suspended'))
def get_catalog_integration_output(credentials: Optional[pulumi.Input[Optional[Union['GetCatalogIntegrationCredentialsArgs', 'GetCatalogIntegrationCredentialsArgsDict']]]] = None,
                                   environment: Optional[pulumi.Input[Union['GetCatalogIntegrationEnvironmentArgs', 'GetCatalogIntegrationEnvironmentArgsDict']]] = None,
                                   id: Optional[pulumi.Input[_builtins.str]] = None,
                                   kafka_cluster: Optional[pulumi.Input[Union['GetCatalogIntegrationKafkaClusterArgs', 'GetCatalogIntegrationKafkaClusterArgsDict']]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCatalogIntegrationResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `CatalogIntegration` describes a Catalog Integration data source.

    ## Example Usage

    ### Option #1: Manage multiple Catalog Integrations in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_catalog_integration(environment={
            "id": staging["id"],
        },
        kafka_cluster={
            "id": staging_confluent_kafka_cluster["id"],
        },
        id="tci-abc123",
        credentials={
            "key": env_admin_tableflow_api_key["id"],
            "secret": env_admin_tableflow_api_key["secret"],
        })
    pulumi.export("retention-ms", example.retention_ms)
    ```

    ### Option #2: Manage a single Catalog Integration in the same Pulumi Stack

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_catalog_integration(id="tci-abc123")
    pulumi.export("retention-ms", example.retention_ms)
    ```


    :param _builtins.str id: The ID of the Catalog Integration, for example, `tci-abc123`.
    """
    __args__ = dict()
    __args__['credentials'] = credentials
    __args__['environment'] = environment
    __args__['id'] = id
    __args__['kafkaCluster'] = kafka_cluster
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getCatalogIntegration:getCatalogIntegration', __args__, opts=opts, typ=GetCatalogIntegrationResult)
    return __ret__.apply(lambda __response__: GetCatalogIntegrationResult(
        aws_glues=pulumi.get(__response__, 'aws_glues'),
        credentials=pulumi.get(__response__, 'credentials'),
        display_name=pulumi.get(__response__, 'display_name'),
        environment=pulumi.get(__response__, 'environment'),
        id=pulumi.get(__response__, 'id'),
        kafka_cluster=pulumi.get(__response__, 'kafka_cluster'),
        snowflakes=pulumi.get(__response__, 'snowflakes'),
        suspended=pulumi.get(__response__, 'suspended')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['IpFilterArgs', 'IpFilter']

@pulumi.input_type
class IpFilterArgs:
    def __init__(__self__, *,
                 filter_name: pulumi.Input[_builtins.str],
                 ip_groups: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 resource_group: pulumi.Input[_builtins.str],
                 operation_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_scope: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a IpFilter resource.
        :param pulumi.Input[_builtins.str] filter_name: A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_groups: A list of IP Groups.
        :param pulumi.Input[_builtins.str] resource_group: Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] operation_groups: Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        :param pulumi.Input[_builtins.str] resource_scope: A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        pulumi.set(__self__, "filter_name", filter_name)
        pulumi.set(__self__, "ip_groups", ip_groups)
        pulumi.set(__self__, "resource_group", resource_group)
        if operation_groups is not None:
            pulumi.set(__self__, "operation_groups", operation_groups)
        if resource_scope is not None:
            pulumi.set(__self__, "resource_scope", resource_scope)

    @_builtins.property
    @pulumi.getter(name="filterName")
    def filter_name(self) -> pulumi.Input[_builtins.str]:
        """
        A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        """
        return pulumi.get(self, "filter_name")

    @filter_name.setter
    def filter_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "filter_name", value)

    @_builtins.property
    @pulumi.getter(name="ipGroups")
    def ip_groups(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A list of IP Groups.
        """
        return pulumi.get(self, "ip_groups")

    @ip_groups.setter
    def ip_groups(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "ip_groups", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> pulumi.Input[_builtins.str]:
        """
        Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        """
        return pulumi.get(self, "resource_group")

    @resource_group.setter
    def resource_group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group", value)

    @_builtins.property
    @pulumi.getter(name="operationGroups")
    def operation_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        """
        return pulumi.get(self, "operation_groups")

    @operation_groups.setter
    def operation_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "operation_groups", value)

    @_builtins.property
    @pulumi.getter(name="resourceScope")
    def resource_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        return pulumi.get(self, "resource_scope")

    @resource_scope.setter
    def resource_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_scope", value)


@pulumi.input_type
class _IpFilterState:
    def __init__(__self__, *,
                 filter_name: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 operation_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_scope: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpFilter resources.
        :param pulumi.Input[_builtins.str] filter_name: A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_groups: A list of IP Groups.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] operation_groups: Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        :param pulumi.Input[_builtins.str] resource_group: Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        :param pulumi.Input[_builtins.str] resource_scope: A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        if filter_name is not None:
            pulumi.set(__self__, "filter_name", filter_name)
        if ip_groups is not None:
            pulumi.set(__self__, "ip_groups", ip_groups)
        if operation_groups is not None:
            pulumi.set(__self__, "operation_groups", operation_groups)
        if resource_group is not None:
            pulumi.set(__self__, "resource_group", resource_group)
        if resource_scope is not None:
            pulumi.set(__self__, "resource_scope", resource_scope)

    @_builtins.property
    @pulumi.getter(name="filterName")
    def filter_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        """
        return pulumi.get(self, "filter_name")

    @filter_name.setter
    def filter_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "filter_name", value)

    @_builtins.property
    @pulumi.getter(name="ipGroups")
    def ip_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of IP Groups.
        """
        return pulumi.get(self, "ip_groups")

    @ip_groups.setter
    def ip_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_groups", value)

    @_builtins.property
    @pulumi.getter(name="operationGroups")
    def operation_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        """
        return pulumi.get(self, "operation_groups")

    @operation_groups.setter
    def operation_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "operation_groups", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        """
        return pulumi.get(self, "resource_group")

    @resource_group.setter
    def resource_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group", value)

    @_builtins.property
    @pulumi.getter(name="resourceScope")
    def resource_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        return pulumi.get(self, "resource_scope")

    @resource_scope.setter
    def resource_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_scope", value)


@pulumi.type_token("confluentcloud:index/ipFilter:IpFilter")
class IpFilter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filter_name: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 operation_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

        `IpFilter` provides an IP Filter resource that enables creating, editing, and deleting IP Filters on Confluent Cloud.

        > **Note:** See [IP Filtering on Confluent Cloud](https://docs.confluent.io/cloud/current/security/access-control/ip-filtering/overview.html) for more details about the IP Filtering feature, its prerequisites, and its limitations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        management_filter = confluentcloud.IpFilter("management-filter",
            filter_name="Management API Rules",
            resource_group="management",
            ip_groups=[example["id"]])
        multiple_filter = confluentcloud.IpFilter("multiple-filter",
            filter_name="Management, Schema, Flink API Rules",
            resource_group="multiple",
            operation_groups=[
                "MANAGEMENT",
                "SCHEMA",
                "FLINK",
            ],
            ip_groups=[example["id"]])
        ```

        ## Import

        You can import an IP Filter by using IP Filter ID, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/ipFilter:IpFilter example ipf-abc123
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] filter_name: A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_groups: A list of IP Groups.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] operation_groups: Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        :param pulumi.Input[_builtins.str] resource_group: Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        :param pulumi.Input[_builtins.str] resource_scope: A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpFilterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

        `IpFilter` provides an IP Filter resource that enables creating, editing, and deleting IP Filters on Confluent Cloud.

        > **Note:** See [IP Filtering on Confluent Cloud](https://docs.confluent.io/cloud/current/security/access-control/ip-filtering/overview.html) for more details about the IP Filtering feature, its prerequisites, and its limitations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        management_filter = confluentcloud.IpFilter("management-filter",
            filter_name="Management API Rules",
            resource_group="management",
            ip_groups=[example["id"]])
        multiple_filter = confluentcloud.IpFilter("multiple-filter",
            filter_name="Management, Schema, Flink API Rules",
            resource_group="multiple",
            operation_groups=[
                "MANAGEMENT",
                "SCHEMA",
                "FLINK",
            ],
            ip_groups=[example["id"]])
        ```

        ## Import

        You can import an IP Filter by using IP Filter ID, for example:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/ipFilter:IpFilter example ipf-abc123
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param IpFilterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpFilterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filter_name: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 operation_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 resource_group: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpFilterArgs.__new__(IpFilterArgs)

            if filter_name is None and not opts.urn:
                raise TypeError("Missing required property 'filter_name'")
            __props__.__dict__["filter_name"] = filter_name
            if ip_groups is None and not opts.urn:
                raise TypeError("Missing required property 'ip_groups'")
            __props__.__dict__["ip_groups"] = ip_groups
            __props__.__dict__["operation_groups"] = operation_groups
            if resource_group is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group'")
            __props__.__dict__["resource_group"] = resource_group
            __props__.__dict__["resource_scope"] = resource_scope
        super(IpFilter, __self__).__init__(
            'confluentcloud:index/ipFilter:IpFilter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            filter_name: Optional[pulumi.Input[_builtins.str]] = None,
            ip_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            operation_groups: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            resource_group: Optional[pulumi.Input[_builtins.str]] = None,
            resource_scope: Optional[pulumi.Input[_builtins.str]] = None) -> 'IpFilter':
        """
        Get an existing IpFilter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] filter_name: A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_groups: A list of IP Groups.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] operation_groups: Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        :param pulumi.Input[_builtins.str] resource_group: Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        :param pulumi.Input[_builtins.str] resource_scope: A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpFilterState.__new__(_IpFilterState)

        __props__.__dict__["filter_name"] = filter_name
        __props__.__dict__["ip_groups"] = ip_groups
        __props__.__dict__["operation_groups"] = operation_groups
        __props__.__dict__["resource_group"] = resource_group
        __props__.__dict__["resource_scope"] = resource_scope
        return IpFilter(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="filterName")
    def filter_name(self) -> pulumi.Output[_builtins.str]:
        """
        A human-readable name for an IP Filter. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        """
        return pulumi.get(self, "filter_name")

    @_builtins.property
    @pulumi.getter(name="ipGroups")
    def ip_groups(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of IP Groups.
        """
        return pulumi.get(self, "ip_groups")

    @_builtins.property
    @pulumi.getter(name="operationGroups")
    def operation_groups(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Scope of resources covered by this IP Filter. Resource group must be set to 'multiple' in order to use this property. During update operations, note that the operation groups passed in will replace the list of existing operation groups (passing in an empty list will remove all operation groups) from the filter (in line with the behavior for `ip_groups` attribute).
        """
        return pulumi.get(self, "operation_groups")

    @_builtins.property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> pulumi.Output[_builtins.str]:
        """
        Scope of resources covered by this IP Filter. Available resource groups include `"management"` and `"multiple"`.
        """
        return pulumi.get(self, "resource_group")

    @_builtins.property
    @pulumi.getter(name="resourceScope")
    def resource_scope(self) -> pulumi.Output[_builtins.str]:
        """
        A CRN that specifies the scope of the IP Filter, specifically the organization or environment. Without specifying this property, the IP Filter would apply to the whole organization. For example, `"crn://confluent.cloud/organization=1111aaaa-11aa-11aa-11aa-111111aaaaaa"` or `data.confluent_organization.resource_name`.
        """
        return pulumi.get(self, "resource_scope")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProviderIntegrationAuthorizationArgs', 'ProviderIntegrationAuthorization']

@pulumi.input_type
class ProviderIntegrationAuthorizationArgs:
    def __init__(__self__, *,
                 environment: pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs'],
                 provider_integration_id: pulumi.Input[_builtins.str],
                 azure: Optional[pulumi.Input['ProviderIntegrationAuthorizationAzureArgs']] = None,
                 gcp: Optional[pulumi.Input['ProviderIntegrationAuthorizationGcpArgs']] = None):
        """
        The set of arguments for constructing a ProviderIntegrationAuthorization resource.
        :param pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] provider_integration_id: The ID of the provider integration to authorize.
        :param pulumi.Input['ProviderIntegrationAuthorizationAzureArgs'] azure: (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        :param pulumi.Input['ProviderIntegrationAuthorizationGcpArgs'] gcp: (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        """
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "provider_integration_id", provider_integration_id)
        if azure is not None:
            pulumi.set(__self__, "azure", azure)
        if gcp is not None:
            pulumi.set(__self__, "gcp", gcp)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs']):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter(name="providerIntegrationId")
    def provider_integration_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the provider integration to authorize.
        """
        return pulumi.get(self, "provider_integration_id")

    @provider_integration_id.setter
    def provider_integration_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provider_integration_id", value)

    @_builtins.property
    @pulumi.getter
    def azure(self) -> Optional[pulumi.Input['ProviderIntegrationAuthorizationAzureArgs']]:
        """
        (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        """
        return pulumi.get(self, "azure")

    @azure.setter
    def azure(self, value: Optional[pulumi.Input['ProviderIntegrationAuthorizationAzureArgs']]):
        pulumi.set(self, "azure", value)

    @_builtins.property
    @pulumi.getter
    def gcp(self) -> Optional[pulumi.Input['ProviderIntegrationAuthorizationGcpArgs']]:
        """
        (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        """
        return pulumi.get(self, "gcp")

    @gcp.setter
    def gcp(self, value: Optional[pulumi.Input['ProviderIntegrationAuthorizationGcpArgs']]):
        pulumi.set(self, "gcp", value)


@pulumi.input_type
class _ProviderIntegrationAuthorizationState:
    def __init__(__self__, *,
                 azure: Optional[pulumi.Input['ProviderIntegrationAuthorizationAzureArgs']] = None,
                 environment: Optional[pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs']] = None,
                 gcp: Optional[pulumi.Input['ProviderIntegrationAuthorizationGcpArgs']] = None,
                 provider_integration_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProviderIntegrationAuthorization resources.
        :param pulumi.Input['ProviderIntegrationAuthorizationAzureArgs'] azure: (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        :param pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input['ProviderIntegrationAuthorizationGcpArgs'] gcp: (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        :param pulumi.Input[_builtins.str] provider_integration_id: The ID of the provider integration to authorize.
        """
        if azure is not None:
            pulumi.set(__self__, "azure", azure)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if gcp is not None:
            pulumi.set(__self__, "gcp", gcp)
        if provider_integration_id is not None:
            pulumi.set(__self__, "provider_integration_id", provider_integration_id)

    @_builtins.property
    @pulumi.getter
    def azure(self) -> Optional[pulumi.Input['ProviderIntegrationAuthorizationAzureArgs']]:
        """
        (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        """
        return pulumi.get(self, "azure")

    @azure.setter
    def azure(self, value: Optional[pulumi.Input['ProviderIntegrationAuthorizationAzureArgs']]):
        pulumi.set(self, "azure", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs']]:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['ProviderIntegrationAuthorizationEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def gcp(self) -> Optional[pulumi.Input['ProviderIntegrationAuthorizationGcpArgs']]:
        """
        (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        """
        return pulumi.get(self, "gcp")

    @gcp.setter
    def gcp(self, value: Optional[pulumi.Input['ProviderIntegrationAuthorizationGcpArgs']]):
        pulumi.set(self, "gcp", value)

    @_builtins.property
    @pulumi.getter(name="providerIntegrationId")
    def provider_integration_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the provider integration to authorize.
        """
        return pulumi.get(self, "provider_integration_id")

    @provider_integration_id.setter
    def provider_integration_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_integration_id", value)


@pulumi.type_token("confluentcloud:index/providerIntegrationAuthorization:ProviderIntegrationAuthorization")
class ProviderIntegrationAuthorization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 azure: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationAzureArgs', 'ProviderIntegrationAuthorizationAzureArgsDict']]] = None,
                 environment: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationEnvironmentArgs', 'ProviderIntegrationAuthorizationEnvironmentArgsDict']]] = None,
                 gcp: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationGcpArgs', 'ProviderIntegrationAuthorizationGcpArgsDict']]] = None,
                 provider_integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        You can import a Provider Integration Authorization by using Environment ID and Provider Integration ID, in the format `<Environment ID>/<Provider Integration ID>`. The following example shows how to import a Provider Integration Authorization:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/providerIntegrationAuthorization:ProviderIntegrationAuthorization main env-abc123/cspi-4xg0q
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ProviderIntegrationAuthorizationAzureArgs', 'ProviderIntegrationAuthorizationAzureArgsDict']] azure: (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        :param pulumi.Input[Union['ProviderIntegrationAuthorizationEnvironmentArgs', 'ProviderIntegrationAuthorizationEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[Union['ProviderIntegrationAuthorizationGcpArgs', 'ProviderIntegrationAuthorizationGcpArgsDict']] gcp: (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        :param pulumi.Input[_builtins.str] provider_integration_id: The ID of the provider integration to authorize.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProviderIntegrationAuthorizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        You can import a Provider Integration Authorization by using Environment ID and Provider Integration ID, in the format `<Environment ID>/<Provider Integration ID>`. The following example shows how to import a Provider Integration Authorization:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/providerIntegrationAuthorization:ProviderIntegrationAuthorization main env-abc123/cspi-4xg0q
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param ProviderIntegrationAuthorizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderIntegrationAuthorizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 azure: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationAzureArgs', 'ProviderIntegrationAuthorizationAzureArgsDict']]] = None,
                 environment: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationEnvironmentArgs', 'ProviderIntegrationAuthorizationEnvironmentArgsDict']]] = None,
                 gcp: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationGcpArgs', 'ProviderIntegrationAuthorizationGcpArgsDict']]] = None,
                 provider_integration_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderIntegrationAuthorizationArgs.__new__(ProviderIntegrationAuthorizationArgs)

            __props__.__dict__["azure"] = azure
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            __props__.__dict__["gcp"] = gcp
            if provider_integration_id is None and not opts.urn:
                raise TypeError("Missing required property 'provider_integration_id'")
            __props__.__dict__["provider_integration_id"] = provider_integration_id
        super(ProviderIntegrationAuthorization, __self__).__init__(
            'confluentcloud:index/providerIntegrationAuthorization:ProviderIntegrationAuthorization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            azure: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationAzureArgs', 'ProviderIntegrationAuthorizationAzureArgsDict']]] = None,
            environment: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationEnvironmentArgs', 'ProviderIntegrationAuthorizationEnvironmentArgsDict']]] = None,
            gcp: Optional[pulumi.Input[Union['ProviderIntegrationAuthorizationGcpArgs', 'ProviderIntegrationAuthorizationGcpArgsDict']]] = None,
            provider_integration_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProviderIntegrationAuthorization':
        """
        Get an existing ProviderIntegrationAuthorization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ProviderIntegrationAuthorizationAzureArgs', 'ProviderIntegrationAuthorizationAzureArgsDict']] azure: (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        :param pulumi.Input[Union['ProviderIntegrationAuthorizationEnvironmentArgs', 'ProviderIntegrationAuthorizationEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[Union['ProviderIntegrationAuthorizationGcpArgs', 'ProviderIntegrationAuthorizationGcpArgsDict']] gcp: (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        :param pulumi.Input[_builtins.str] provider_integration_id: The ID of the provider integration to authorize.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProviderIntegrationAuthorizationState.__new__(_ProviderIntegrationAuthorizationState)

        __props__.__dict__["azure"] = azure
        __props__.__dict__["environment"] = environment
        __props__.__dict__["gcp"] = gcp
        __props__.__dict__["provider_integration_id"] = provider_integration_id
        return ProviderIntegrationAuthorization(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def azure(self) -> pulumi.Output[Optional['outputs.ProviderIntegrationAuthorizationAzure']]:
        """
        (Optional Configuration Block) Azure-specific configuration details. It supports the following:
        """
        return pulumi.get(self, "azure")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.ProviderIntegrationAuthorizationEnvironment']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def gcp(self) -> pulumi.Output[Optional['outputs.ProviderIntegrationAuthorizationGcp']]:
        """
        (Optional Configuration Block) GCP-specific configuration details. It supports the following:
        """
        return pulumi.get(self, "gcp")

    @_builtins.property
    @pulumi.getter(name="providerIntegrationId")
    def provider_integration_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the provider integration to authorize.
        """
        return pulumi.get(self, "provider_integration_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProviderIntegrationSetupArgs', 'ProviderIntegrationSetup']

@pulumi.input_type
class ProviderIntegrationSetupArgs:
    def __init__(__self__, *,
                 cloud: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 environment: pulumi.Input['ProviderIntegrationSetupEnvironmentArgs']):
        """
        The set of arguments for constructing a ProviderIntegrationSetup resource.
        :param pulumi.Input[_builtins.str] cloud: The cloud service provider. Supported values are `AZURE` and `GCP`.
        :param pulumi.Input[_builtins.str] display_name: The name of the Provider Integration.
        :param pulumi.Input['ProviderIntegrationSetupEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        pulumi.set(__self__, "cloud", cloud)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "environment", environment)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Input[_builtins.str]:
        """
        The cloud service provider. Supported values are `AZURE` and `GCP`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Provider Integration.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input['ProviderIntegrationSetupEnvironmentArgs']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input['ProviderIntegrationSetupEnvironmentArgs']):
        pulumi.set(self, "environment", value)


@pulumi.input_type
class _ProviderIntegrationSetupState:
    def __init__(__self__, *,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input['ProviderIntegrationSetupEnvironmentArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 usages: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering ProviderIntegrationSetup resources.
        :param pulumi.Input[_builtins.str] cloud: The cloud service provider. Supported values are `AZURE` and `GCP`.
        :param pulumi.Input[_builtins.str] display_name: The name of the Provider Integration.
        :param pulumi.Input['ProviderIntegrationSetupEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] status: (Required String) The status of the Provider Integration. Values are `DRAFT` and `CREATED`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] usages: (Required List of Strings) List of resource CRNs where this provider integration is being used.
        """
        if cloud is not None:
            pulumi.set(__self__, "cloud", cloud)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if usages is not None:
            pulumi.set(__self__, "usages", usages)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cloud service provider. Supported values are `AZURE` and `GCP`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Provider Integration.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['ProviderIntegrationSetupEnvironmentArgs']]:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['ProviderIntegrationSetupEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required String) The status of the Provider Integration. Values are `DRAFT` and `CREATED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def usages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        (Required List of Strings) List of resource CRNs where this provider integration is being used.
        """
        return pulumi.get(self, "usages")

    @usages.setter
    def usages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "usages", value)


@pulumi.type_token("confluentcloud:index/providerIntegrationSetup:ProviderIntegrationSetup")
class ProviderIntegrationSetup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['ProviderIntegrationSetupEnvironmentArgs', 'ProviderIntegrationSetupEnvironmentArgsDict']]] = None,
                 __props__=None):
        """
        ## Example Usage

        ### Azure Provider Integration

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        staging = confluentcloud.Environment("staging",
            display_name="Staging",
            stream_governance={
                "package": "ESSENTIALS",
            })
        azure = confluentcloud.ProviderIntegrationSetup("azure",
            environment={
                "id": staging.id,
            },
            display_name="azure-integration",
            cloud="AZURE")
        # Configure and validate the Azure integration
        azure_provider_integration_authorization = confluentcloud.ProviderIntegrationAuthorization("azure",
            provider_integration_id=azure.id,
            environment={
                "id": staging.id,
            },
            azure={
                "customer_azure_tenant_id": "12345678-1234-1234-1234-123456789abc",
            })
        ```

        ### GCP Provider Integration

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        gcp = confluentcloud.ProviderIntegrationSetup("gcp",
            environment={
                "id": staging["id"],
            },
            display_name="gcp-integration",
            cloud="GCP")
        # Configure and validate the GCP integration
        gcp_provider_integration_authorization = confluentcloud.ProviderIntegrationAuthorization("gcp",
            provider_integration_id=gcp.id,
            environment={
                "id": staging["id"],
            },
            gcp={
                "customer_google_service_account": "my-sa@my-project.iam.gserviceaccount.com",
            })
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `ProviderIntegrationSetup` resource:
        * provider-integration-azure: Complete Azure Provider Integration setup
        * provider-integration-gcp: Complete GCP Provider Integration setup

        ## Import

        You can import a Provider Integration by using Environment ID and Provider Integration ID, in the format `<Environment ID>/<Provider Integration ID>`. The following example shows how to import a Provider Integration:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/providerIntegrationSetup:ProviderIntegrationSetup main env-abc123/cspi-4xg0q
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud: The cloud service provider. Supported values are `AZURE` and `GCP`.
        :param pulumi.Input[_builtins.str] display_name: The name of the Provider Integration.
        :param pulumi.Input[Union['ProviderIntegrationSetupEnvironmentArgs', 'ProviderIntegrationSetupEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProviderIntegrationSetupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ### Azure Provider Integration

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        staging = confluentcloud.Environment("staging",
            display_name="Staging",
            stream_governance={
                "package": "ESSENTIALS",
            })
        azure = confluentcloud.ProviderIntegrationSetup("azure",
            environment={
                "id": staging.id,
            },
            display_name="azure-integration",
            cloud="AZURE")
        # Configure and validate the Azure integration
        azure_provider_integration_authorization = confluentcloud.ProviderIntegrationAuthorization("azure",
            provider_integration_id=azure.id,
            environment={
                "id": staging.id,
            },
            azure={
                "customer_azure_tenant_id": "12345678-1234-1234-1234-123456789abc",
            })
        ```

        ### GCP Provider Integration

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        gcp = confluentcloud.ProviderIntegrationSetup("gcp",
            environment={
                "id": staging["id"],
            },
            display_name="gcp-integration",
            cloud="GCP")
        # Configure and validate the GCP integration
        gcp_provider_integration_authorization = confluentcloud.ProviderIntegrationAuthorization("gcp",
            provider_integration_id=gcp.id,
            environment={
                "id": staging["id"],
            },
            gcp={
                "customer_google_service_account": "my-sa@my-project.iam.gserviceaccount.com",
            })
        ```

        ## Getting Started

        The following end-to-end examples might help to get started with `ProviderIntegrationSetup` resource:
        * provider-integration-azure: Complete Azure Provider Integration setup
        * provider-integration-gcp: Complete GCP Provider Integration setup

        ## Import

        You can import a Provider Integration by using Environment ID and Provider Integration ID, in the format `<Environment ID>/<Provider Integration ID>`. The following example shows how to import a Provider Integration:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/providerIntegrationSetup:ProviderIntegrationSetup main env-abc123/cspi-4xg0q
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param ProviderIntegrationSetupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderIntegrationSetupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['ProviderIntegrationSetupEnvironmentArgs', 'ProviderIntegrationSetupEnvironmentArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderIntegrationSetupArgs.__new__(ProviderIntegrationSetupArgs)

            if cloud is None and not opts.urn:
                raise TypeError("Missing required property 'cloud'")
            __props__.__dict__["cloud"] = cloud
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            __props__.__dict__["status"] = None
            __props__.__dict__["usages"] = None
        super(ProviderIntegrationSetup, __self__).__init__(
            'confluentcloud:index/providerIntegrationSetup:ProviderIntegrationSetup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cloud: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[Union['ProviderIntegrationSetupEnvironmentArgs', 'ProviderIntegrationSetupEnvironmentArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            usages: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'ProviderIntegrationSetup':
        """
        Get an existing ProviderIntegrationSetup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud: The cloud service provider. Supported values are `AZURE` and `GCP`.
        :param pulumi.Input[_builtins.str] display_name: The name of the Provider Integration.
        :param pulumi.Input[Union['ProviderIntegrationSetupEnvironmentArgs', 'ProviderIntegrationSetupEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] status: (Required String) The status of the Provider Integration. Values are `DRAFT` and `CREATED`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] usages: (Required List of Strings) List of resource CRNs where this provider integration is being used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProviderIntegrationSetupState.__new__(_ProviderIntegrationSetupState)

        __props__.__dict__["cloud"] = cloud
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["environment"] = environment
        __props__.__dict__["status"] = status
        __props__.__dict__["usages"] = usages
        return ProviderIntegrationSetup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Output[_builtins.str]:
        """
        The cloud service provider. Supported values are `AZURE` and `GCP`.
        """
        return pulumi.get(self, "cloud")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Provider Integration.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.ProviderIntegrationSetupEnvironment']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        (Required String) The status of the Provider Integration. Values are `DRAFT` and `CREATED`.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def usages(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        (Required List of Strings) List of resource CRNs where this provider integration is being used.
        """
        return pulumi.get(self, "usages")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomConnectorPluginVersionArgs', 'CustomConnectorPluginVersion']

@pulumi.input_type
class CustomConnectorPluginVersionArgs:
    def __init__(__self__, *,
                 cloud: pulumi.Input[_builtins.str],
                 connector_classes: pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]],
                 environment: pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs'],
                 filename: pulumi.Input[_builtins.str],
                 plugin_id: pulumi.Input[_builtins.str],
                 version: pulumi.Input[_builtins.str],
                 documentation_link: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive_config_properties: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a CustomConnectorPluginVersion resource.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]] connector_classes: The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        :param pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] filename: The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        :param pulumi.Input[_builtins.str] plugin_id: The ID of the plugin created using `Plugin` resource, or through other ways.
        :param pulumi.Input[_builtins.str] version: The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        :param pulumi.Input[_builtins.str] documentation_link: The documentation link of the Custom Connector Plugin Version.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] sensitive_config_properties: The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        """
        pulumi.set(__self__, "cloud", cloud)
        pulumi.set(__self__, "connector_classes", connector_classes)
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "filename", filename)
        pulumi.set(__self__, "plugin_id", plugin_id)
        pulumi.set(__self__, "version", version)
        if documentation_link is not None:
            pulumi.set(__self__, "documentation_link", documentation_link)
        if sensitive_config_properties is not None:
            pulumi.set(__self__, "sensitive_config_properties", sensitive_config_properties)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Input[_builtins.str]:
        """
        Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="connectorClasses")
    def connector_classes(self) -> pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]]:
        """
        The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        """
        return pulumi.get(self, "connector_classes")

    @connector_classes.setter
    def connector_classes(self, value: pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]]):
        pulumi.set(self, "connector_classes", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs']):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def filename(self) -> pulumi.Input[_builtins.str]:
        """
        The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        """
        return pulumi.get(self, "filename")

    @filename.setter
    def filename(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "filename", value)

    @_builtins.property
    @pulumi.getter(name="pluginId")
    def plugin_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the plugin created using `Plugin` resource, or through other ways.
        """
        return pulumi.get(self, "plugin_id")

    @plugin_id.setter
    def plugin_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "plugin_id", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Input[_builtins.str]:
        """
        The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version", value)

    @_builtins.property
    @pulumi.getter(name="documentationLink")
    def documentation_link(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The documentation link of the Custom Connector Plugin Version.
        """
        return pulumi.get(self, "documentation_link")

    @documentation_link.setter
    def documentation_link(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "documentation_link", value)

    @_builtins.property
    @pulumi.getter(name="sensitiveConfigProperties")
    def sensitive_config_properties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        """
        return pulumi.get(self, "sensitive_config_properties")

    @sensitive_config_properties.setter
    def sensitive_config_properties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "sensitive_config_properties", value)


@pulumi.input_type
class _CustomConnectorPluginVersionState:
    def __init__(__self__, *,
                 api_version: Optional[pulumi.Input[_builtins.str]] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_classes: Optional[pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]]] = None,
                 documentation_link: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs']] = None,
                 filename: Optional[pulumi.Input[_builtins.str]] = None,
                 kind: Optional[pulumi.Input[_builtins.str]] = None,
                 plugin_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive_config_properties: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomConnectorPluginVersion resources.
        :param pulumi.Input[_builtins.str] api_version: (Required String) The API Version of the schema version of the plugin version, for example, `ccpm/v1`.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]] connector_classes: The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        :param pulumi.Input[_builtins.str] documentation_link: The documentation link of the Custom Connector Plugin Version.
        :param pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs'] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] filename: The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        :param pulumi.Input[_builtins.str] kind: (Required String) The kind of the Plugin Version, for example, `CustomConnectPluginVersion`.
        :param pulumi.Input[_builtins.str] plugin_id: The ID of the plugin created using `Plugin` resource, or through other ways.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] sensitive_config_properties: The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        :param pulumi.Input[_builtins.str] version: The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        """
        if api_version is not None:
            pulumi.set(__self__, "api_version", api_version)
        if cloud is not None:
            pulumi.set(__self__, "cloud", cloud)
        if connector_classes is not None:
            pulumi.set(__self__, "connector_classes", connector_classes)
        if documentation_link is not None:
            pulumi.set(__self__, "documentation_link", documentation_link)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if filename is not None:
            pulumi.set(__self__, "filename", filename)
        if kind is not None:
            pulumi.set(__self__, "kind", kind)
        if plugin_id is not None:
            pulumi.set(__self__, "plugin_id", plugin_id)
        if sensitive_config_properties is not None:
            pulumi.set(__self__, "sensitive_config_properties", sensitive_config_properties)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required String) The API Version of the schema version of the plugin version, for example, `ccpm/v1`.
        """
        return pulumi.get(self, "api_version")

    @api_version.setter
    def api_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "api_version", value)

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        """
        return pulumi.get(self, "cloud")

    @cloud.setter
    def cloud(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cloud", value)

    @_builtins.property
    @pulumi.getter(name="connectorClasses")
    def connector_classes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]]]:
        """
        The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        """
        return pulumi.get(self, "connector_classes")

    @connector_classes.setter
    def connector_classes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomConnectorPluginVersionConnectorClassArgs']]]]):
        pulumi.set(self, "connector_classes", value)

    @_builtins.property
    @pulumi.getter(name="documentationLink")
    def documentation_link(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The documentation link of the Custom Connector Plugin Version.
        """
        return pulumi.get(self, "documentation_link")

    @documentation_link.setter
    def documentation_link(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "documentation_link", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs']]:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input['CustomConnectorPluginVersionEnvironmentArgs']]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def filename(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        """
        return pulumi.get(self, "filename")

    @filename.setter
    def filename(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "filename", value)

    @_builtins.property
    @pulumi.getter
    def kind(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required String) The kind of the Plugin Version, for example, `CustomConnectPluginVersion`.
        """
        return pulumi.get(self, "kind")

    @kind.setter
    def kind(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "kind", value)

    @_builtins.property
    @pulumi.getter(name="pluginId")
    def plugin_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the plugin created using `Plugin` resource, or through other ways.
        """
        return pulumi.get(self, "plugin_id")

    @plugin_id.setter
    def plugin_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "plugin_id", value)

    @_builtins.property
    @pulumi.getter(name="sensitiveConfigProperties")
    def sensitive_config_properties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        """
        return pulumi.get(self, "sensitive_config_properties")

    @sensitive_config_properties.setter
    def sensitive_config_properties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "sensitive_config_properties", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.type_token("confluentcloud:index/customConnectorPluginVersion:CustomConnectorPluginVersion")
class CustomConnectorPluginVersion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_classes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomConnectorPluginVersionConnectorClassArgs', 'CustomConnectorPluginVersionConnectorClassArgsDict']]]]] = None,
                 documentation_link: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['CustomConnectorPluginVersionEnvironmentArgs', 'CustomConnectorPluginVersionEnvironmentArgsDict']]] = None,
                 filename: Optional[pulumi.Input[_builtins.str]] = None,
                 plugin_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive_config_properties: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        source = confluentcloud.CustomConnectorPluginVersion("source",
            version="v1.2.4",
            cloud="AWS",
            documentation_link="https://www.confluent.io/hub/confluentinc/kafka-connect-datagen",
            connector_classes=[{
                "connector_class_name": "io.confluent.kafka.connect.datagen.DatagenConnector",
                "connector_type": "SOURCE",
            }],
            sensitive_config_properties=[],
            filename="confluentinc-kafka-connect-datagen-0.6.2.zip",
            plugin_id="ccp-dev-123",
            environment={
                "id": "env-devc0k7oxp",
            },
            opts = pulumi.ResourceOptions(depends_on=[plugin]))
        ```

        ## Import

        You can import a Custom Connector Plugin by using a Custom Connector Plugin ID, in the format `<Environment ID>/<Plugin ID>/<Version ID>`. The following example shows how to import a Custom Connector Plugin:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/customConnectorPluginVersion:CustomConnectorPluginVersion main env-123/plug-123/ccp-ver123xyz
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['CustomConnectorPluginVersionConnectorClassArgs', 'CustomConnectorPluginVersionConnectorClassArgsDict']]]] connector_classes: The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        :param pulumi.Input[_builtins.str] documentation_link: The documentation link of the Custom Connector Plugin Version.
        :param pulumi.Input[Union['CustomConnectorPluginVersionEnvironmentArgs', 'CustomConnectorPluginVersionEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] filename: The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        :param pulumi.Input[_builtins.str] plugin_id: The ID of the plugin created using `Plugin` resource, or through other ways.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] sensitive_config_properties: The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        :param pulumi.Input[_builtins.str] version: The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomConnectorPluginVersionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_confluentcloud as confluentcloud

        source = confluentcloud.CustomConnectorPluginVersion("source",
            version="v1.2.4",
            cloud="AWS",
            documentation_link="https://www.confluent.io/hub/confluentinc/kafka-connect-datagen",
            connector_classes=[{
                "connector_class_name": "io.confluent.kafka.connect.datagen.DatagenConnector",
                "connector_type": "SOURCE",
            }],
            sensitive_config_properties=[],
            filename="confluentinc-kafka-connect-datagen-0.6.2.zip",
            plugin_id="ccp-dev-123",
            environment={
                "id": "env-devc0k7oxp",
            },
            opts = pulumi.ResourceOptions(depends_on=[plugin]))
        ```

        ## Import

        You can import a Custom Connector Plugin by using a Custom Connector Plugin ID, in the format `<Environment ID>/<Plugin ID>/<Version ID>`. The following example shows how to import a Custom Connector Plugin:

        $ export CONFLUENT_CLOUD_API_KEY="<cloud_api_key>"

        $ export CONFLUENT_CLOUD_API_SECRET="<cloud_api_secret>"

        ```sh
        $ pulumi import confluentcloud:index/customConnectorPluginVersion:CustomConnectorPluginVersion main env-123/plug-123/ccp-ver123xyz
        ```

        !> **Warning:** Do not forget to delete terminal command history afterwards for security purposes.

        :param str resource_name: The name of the resource.
        :param CustomConnectorPluginVersionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomConnectorPluginVersionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cloud: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_classes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomConnectorPluginVersionConnectorClassArgs', 'CustomConnectorPluginVersionConnectorClassArgsDict']]]]] = None,
                 documentation_link: Optional[pulumi.Input[_builtins.str]] = None,
                 environment: Optional[pulumi.Input[Union['CustomConnectorPluginVersionEnvironmentArgs', 'CustomConnectorPluginVersionEnvironmentArgsDict']]] = None,
                 filename: Optional[pulumi.Input[_builtins.str]] = None,
                 plugin_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive_config_properties: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomConnectorPluginVersionArgs.__new__(CustomConnectorPluginVersionArgs)

            if cloud is None and not opts.urn:
                raise TypeError("Missing required property 'cloud'")
            __props__.__dict__["cloud"] = cloud
            if connector_classes is None and not opts.urn:
                raise TypeError("Missing required property 'connector_classes'")
            __props__.__dict__["connector_classes"] = connector_classes
            __props__.__dict__["documentation_link"] = documentation_link
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            if filename is None and not opts.urn:
                raise TypeError("Missing required property 'filename'")
            __props__.__dict__["filename"] = filename
            if plugin_id is None and not opts.urn:
                raise TypeError("Missing required property 'plugin_id'")
            __props__.__dict__["plugin_id"] = plugin_id
            __props__.__dict__["sensitive_config_properties"] = sensitive_config_properties
            if version is None and not opts.urn:
                raise TypeError("Missing required property 'version'")
            __props__.__dict__["version"] = version
            __props__.__dict__["api_version"] = None
            __props__.__dict__["kind"] = None
        super(CustomConnectorPluginVersion, __self__).__init__(
            'confluentcloud:index/customConnectorPluginVersion:CustomConnectorPluginVersion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_version: Optional[pulumi.Input[_builtins.str]] = None,
            cloud: Optional[pulumi.Input[_builtins.str]] = None,
            connector_classes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomConnectorPluginVersionConnectorClassArgs', 'CustomConnectorPluginVersionConnectorClassArgsDict']]]]] = None,
            documentation_link: Optional[pulumi.Input[_builtins.str]] = None,
            environment: Optional[pulumi.Input[Union['CustomConnectorPluginVersionEnvironmentArgs', 'CustomConnectorPluginVersionEnvironmentArgsDict']]] = None,
            filename: Optional[pulumi.Input[_builtins.str]] = None,
            kind: Optional[pulumi.Input[_builtins.str]] = None,
            plugin_id: Optional[pulumi.Input[_builtins.str]] = None,
            sensitive_config_properties: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            version: Optional[pulumi.Input[_builtins.str]] = None) -> 'CustomConnectorPluginVersion':
        """
        Get an existing CustomConnectorPluginVersion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] api_version: (Required String) The API Version of the schema version of the plugin version, for example, `ccpm/v1`.
        :param pulumi.Input[_builtins.str] cloud: Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['CustomConnectorPluginVersionConnectorClassArgs', 'CustomConnectorPluginVersionConnectorClassArgsDict']]]] connector_classes: The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        :param pulumi.Input[_builtins.str] documentation_link: The documentation link of the Custom Connector Plugin Version.
        :param pulumi.Input[Union['CustomConnectorPluginVersionEnvironmentArgs', 'CustomConnectorPluginVersionEnvironmentArgsDict']] environment: Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        :param pulumi.Input[_builtins.str] filename: The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        :param pulumi.Input[_builtins.str] kind: (Required String) The kind of the Plugin Version, for example, `CustomConnectPluginVersion`.
        :param pulumi.Input[_builtins.str] plugin_id: The ID of the plugin created using `Plugin` resource, or through other ways.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] sensitive_config_properties: The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        :param pulumi.Input[_builtins.str] version: The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomConnectorPluginVersionState.__new__(_CustomConnectorPluginVersionState)

        __props__.__dict__["api_version"] = api_version
        __props__.__dict__["cloud"] = cloud
        __props__.__dict__["connector_classes"] = connector_classes
        __props__.__dict__["documentation_link"] = documentation_link
        __props__.__dict__["environment"] = environment
        __props__.__dict__["filename"] = filename
        __props__.__dict__["kind"] = kind
        __props__.__dict__["plugin_id"] = plugin_id
        __props__.__dict__["sensitive_config_properties"] = sensitive_config_properties
        __props__.__dict__["version"] = version
        return CustomConnectorPluginVersion(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apiVersion")
    def api_version(self) -> pulumi.Output[_builtins.str]:
        """
        (Required String) The API Version of the schema version of the plugin version, for example, `ccpm/v1`.
        """
        return pulumi.get(self, "api_version")

    @_builtins.property
    @pulumi.getter
    def cloud(self) -> pulumi.Output[_builtins.str]:
        """
        Cloud provider where the Custom Connector Plugin Version archive is uploaded. Accepted values are: `AWS`, `AZURE`, `GCP`.
        """
        return pulumi.get(self, "cloud")

    @_builtins.property
    @pulumi.getter(name="connectorClasses")
    def connector_classes(self) -> pulumi.Output[Sequence['outputs.CustomConnectorPluginVersionConnectorClass']]:
        """
        The Java class name or alias for the connector. You can get the connector class from the connector documentation provided by the developer.
        """
        return pulumi.get(self, "connector_classes")

    @_builtins.property
    @pulumi.getter(name="documentationLink")
    def documentation_link(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The documentation link of the Custom Connector Plugin Version.
        """
        return pulumi.get(self, "documentation_link")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output['outputs.CustomConnectorPluginVersionEnvironment']:
        """
        Environment objects represent an isolated namespace for your Confluent resources for organizational purposes.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def filename(self) -> pulumi.Output[_builtins.str]:
        """
        The path to the Custom Connector Plugin Version archive to be uploaded. Accepted archive formats are: `.jar`, `.zip`.
        """
        return pulumi.get(self, "filename")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> pulumi.Output[_builtins.str]:
        """
        (Required String) The kind of the Plugin Version, for example, `CustomConnectPluginVersion`.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter(name="pluginId")
    def plugin_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the plugin created using `Plugin` resource, or through other ways.
        """
        return pulumi.get(self, "plugin_id")

    @_builtins.property
    @pulumi.getter(name="sensitiveConfigProperties")
    def sensitive_config_properties(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of sensitive properties. A sensitive property is a connector configuration property that must be hidden after a user enters the property value when setting up the connector, for example, passwords, keys, and tokens. Refer to the developer documentation and add all required and optional sensitive properties that a user could potentially configure for the connector. Marking a property as sensitive ensures that these fields are handled appropriately within the Confluent infrastructure. This includes masking fields, for example in exception logging, and encrypting field values in the underlying data store. You must identify all sensitive properties. Failure to identify sensitive properties can result in the sensitive property value being stored in plain text rather than in encrypted format. Only add connector-specific sensitive properties. Kafka keys, passwords, and service account information should not be entered here.
        """
        return pulumi.get(self, "sensitive_config_properties")

    @_builtins.property
    @pulumi.getter
    def version(self) -> pulumi.Output[_builtins.str]:
        """
        The version number of the plugin version we want to create. This must start with the character `v` and follow semantic versioning.
        """
        return pulumi.get(self, "version")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetIpGroupResult',
    'AwaitableGetIpGroupResult',
    'get_ip_group',
    'get_ip_group_output',
]

@pulumi.output_type
class GetIpGroupResult:
    """
    A collection of values returned by getIpGroup.
    """
    def __init__(__self__, cidr_blocks=None, group_name=None, id=None):
        if cidr_blocks and not isinstance(cidr_blocks, list):
            raise TypeError("Expected argument 'cidr_blocks' to be a list")
        pulumi.set(__self__, "cidr_blocks", cidr_blocks)
        if group_name and not isinstance(group_name, str):
            raise TypeError("Expected argument 'group_name' to be a str")
        pulumi.set(__self__, "group_name", group_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter(name="cidrBlocks")
    def cidr_blocks(self) -> Sequence[_builtins.str]:
        """
        (Required List of Strings) A list of CIDRs.
        """
        return pulumi.get(self, "cidr_blocks")

    @_builtins.property
    @pulumi.getter(name="groupName")
    def group_name(self) -> _builtins.str:
        """
        (Required String) A human-readable name for an IP Group. Can contain any unicode letter or number, the ASCII space character, or any of the following special characters: `[`, `]`, `|`, `&`, `+`, `-`, `_`, `/`, `.`, `,`.
        """
        return pulumi.get(self, "group_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")


class AwaitableGetIpGroupResult(GetIpGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpGroupResult(
            cidr_blocks=self.cidr_blocks,
            group_name=self.group_name,
            id=self.id)


def get_ip_group(id: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpGroupResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `IpGroup` describes an IP Group data source.

    > **Note:** See [IP Filtering on Confluent Cloud](https://docs.confluent.io/cloud/current/security/access-control/ip-filtering/overview.html) for more details about the IP Filtering feature, its prerequisites, and its limitations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_ip_group(id="ipg-abc123")
    pulumi.export("example", example)
    ```


    :param _builtins.str id: The ID of the IP Group (e.g., `ipg-abc123`).
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getIpGroup:getIpGroup', __args__, opts=opts, typ=GetIpGroupResult).value

    return AwaitableGetIpGroupResult(
        cidr_blocks=pulumi.get(__ret__, 'cidr_blocks'),
        group_name=pulumi.get(__ret__, 'group_name'),
        id=pulumi.get(__ret__, 'id'))
def get_ip_group_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpGroupResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `IpGroup` describes an IP Group data source.

    > **Note:** See [IP Filtering on Confluent Cloud](https://docs.confluent.io/cloud/current/security/access-control/ip-filtering/overview.html) for more details about the IP Filtering feature, its prerequisites, and its limitations.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    example = confluentcloud.get_ip_group(id="ipg-abc123")
    pulumi.export("example", example)
    ```


    :param _builtins.str id: The ID of the IP Group (e.g., `ipg-abc123`).
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getIpGroup:getIpGroup', __args__, opts=opts, typ=GetIpGroupResult)
    return __ret__.apply(lambda __response__: GetIpGroupResult(
        cidr_blocks=pulumi.get(__response__, 'cidr_blocks'),
        group_name=pulumi.get(__response__, 'group_name'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGatewaysResult',
    'AwaitableGetGatewaysResult',
    'get_gateways',
    'get_gateways_output',
]

@pulumi.output_type
class GetGatewaysResult:
    """
    A collection of values returned by getGateways.
    """
    def __init__(__self__, environment=None, filter=None, gateways=None, id=None):
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if filter and not isinstance(filter, dict):
            raise TypeError("Expected argument 'filter' to be a dict")
        pulumi.set(__self__, "filter", filter)
        if gateways and not isinstance(gateways, list):
            raise TypeError("Expected argument 'gateways' to be a list")
        pulumi.set(__self__, "gateways", gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetGatewaysEnvironmentResult':
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def filter(self) -> Optional['outputs.GetGatewaysFilterResult']:
        return pulumi.get(self, "filter")

    @_builtins.property
    @pulumi.getter
    def gateways(self) -> Sequence['outputs.GetGatewaysGatewayResult']:
        """
        (List of Object) List of Gateways. Each gateway object exports the following attributes:
        """
        return pulumi.get(self, "gateways")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetGatewaysResult(GetGatewaysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewaysResult(
            environment=self.environment,
            filter=self.filter,
            gateways=self.gateways,
            id=self.id)


def get_gateways(environment: Optional[Union['GetGatewaysEnvironmentArgs', 'GetGatewaysEnvironmentArgsDict']] = None,
                 filter: Optional[Union['GetGatewaysFilterArgs', 'GetGatewaysFilterArgsDict']] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewaysResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_gateways` describes a Gateways data source that allows you to filter and list multiple Gateways.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    all = confluentcloud.get_gateways(environment={
        "id": "env-123abc",
    })
    ready_ingress = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "gateway_types": ["AwsIngressPrivateLink"],
            "phases": ["READY"],
        })
    us_east = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "regions": ["us-east-1"],
            "display_names": ["prod-gateway-ingress-use1"],
        })
    pulumi.export("allGateways", all.gateways)
    pulumi.export("readyIngressGateways", ready_ingress.gateways)
    ```
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['filter'] = filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getGateways:getGateways', __args__, opts=opts, typ=GetGatewaysResult).value

    return AwaitableGetGatewaysResult(
        environment=pulumi.get(__ret__, 'environment'),
        filter=pulumi.get(__ret__, 'filter'),
        gateways=pulumi.get(__ret__, 'gateways'),
        id=pulumi.get(__ret__, 'id'))
def get_gateways_output(environment: Optional[pulumi.Input[Union['GetGatewaysEnvironmentArgs', 'GetGatewaysEnvironmentArgsDict']]] = None,
                        filter: Optional[pulumi.Input[Optional[Union['GetGatewaysFilterArgs', 'GetGatewaysFilterArgsDict']]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGatewaysResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `get_gateways` describes a Gateways data source that allows you to filter and list multiple Gateways.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_confluentcloud as confluentcloud

    all = confluentcloud.get_gateways(environment={
        "id": "env-123abc",
    })
    ready_ingress = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "gateway_types": ["AwsIngressPrivateLink"],
            "phases": ["READY"],
        })
    us_east = confluentcloud.get_gateways(environment={
            "id": "env-123abc",
        },
        filter={
            "regions": ["us-east-1"],
            "display_names": ["prod-gateway-ingress-use1"],
        })
    pulumi.export("allGateways", all.gateways)
    pulumi.export("readyIngressGateways", ready_ingress.gateways)
    ```
    """
    __args__ = dict()
    __args__['environment'] = environment
    __args__['filter'] = filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getGateways:getGateways', __args__, opts=opts, typ=GetGatewaysResult)
    return __ret__.apply(lambda __response__: GetGatewaysResult(
        environment=pulumi.get(__response__, 'environment'),
        filter=pulumi.get(__response__, 'filter'),
        gateways=pulumi.get(__response__, 'gateways'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFlinkConnectionResult',
    'AwaitableGetFlinkConnectionResult',
    'get_flink_connection',
    'get_flink_connection_output',
]

@pulumi.output_type
class GetFlinkConnectionResult:
    """
    A collection of values returned by getFlinkConnection.
    """
    def __init__(__self__, compute_pool=None, credentials=None, data=None, display_name=None, endpoint=None, environment=None, id=None, organization=None, principal=None, rest_endpoint=None, status=None, status_detail=None, type=None):
        if compute_pool and not isinstance(compute_pool, dict):
            raise TypeError("Expected argument 'compute_pool' to be a dict")
        pulumi.set(__self__, "compute_pool", compute_pool)
        if credentials and not isinstance(credentials, dict):
            raise TypeError("Expected argument 'credentials' to be a dict")
        pulumi.set(__self__, "credentials", credentials)
        if data and not isinstance(data, str):
            raise TypeError("Expected argument 'data' to be a str")
        pulumi.set(__self__, "data", data)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if environment and not isinstance(environment, dict):
            raise TypeError("Expected argument 'environment' to be a dict")
        pulumi.set(__self__, "environment", environment)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if organization and not isinstance(organization, dict):
            raise TypeError("Expected argument 'organization' to be a dict")
        pulumi.set(__self__, "organization", organization)
        if principal and not isinstance(principal, dict):
            raise TypeError("Expected argument 'principal' to be a dict")
        pulumi.set(__self__, "principal", principal)
        if rest_endpoint and not isinstance(rest_endpoint, str):
            raise TypeError("Expected argument 'rest_endpoint' to be a str")
        pulumi.set(__self__, "rest_endpoint", rest_endpoint)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if status_detail and not isinstance(status_detail, str):
            raise TypeError("Expected argument 'status_detail' to be a str")
        pulumi.set(__self__, "status_detail", status_detail)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="computePool")
    def compute_pool(self) -> 'outputs.GetFlinkConnectionComputePoolResult':
        return pulumi.get(self, "compute_pool")

    @_builtins.property
    @pulumi.getter
    def credentials(self) -> Optional['outputs.GetFlinkConnectionCredentialsResult']:
        return pulumi.get(self, "credentials")

    @_builtins.property
    @pulumi.getter
    def data(self) -> _builtins.str:
        """
        (Required String) The authentication data of the Flink Connection.
        """
        return pulumi.get(self, "data")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        (Required String) The endpoint of the Flink Connection, for example, `https://api.openai.com/v1/chat/completions`
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> 'outputs.GetFlinkConnectionEnvironmentResult':
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def organization(self) -> 'outputs.GetFlinkConnectionOrganizationResult':
        return pulumi.get(self, "organization")

    @_builtins.property
    @pulumi.getter
    def principal(self) -> 'outputs.GetFlinkConnectionPrincipalResult':
        return pulumi.get(self, "principal")

    @_builtins.property
    @pulumi.getter(name="restEndpoint")
    def rest_endpoint(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "rest_endpoint")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        (Required String) The status of the Flink Connection.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="statusDetail")
    def status_detail(self) -> _builtins.str:
        """
        (Required String) The status details of the Flink Connection.
        -
        """
        return pulumi.get(self, "status_detail")

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "type")


class AwaitableGetFlinkConnectionResult(GetFlinkConnectionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFlinkConnectionResult(
            compute_pool=self.compute_pool,
            credentials=self.credentials,
            data=self.data,
            display_name=self.display_name,
            endpoint=self.endpoint,
            environment=self.environment,
            id=self.id,
            organization=self.organization,
            principal=self.principal,
            rest_endpoint=self.rest_endpoint,
            status=self.status,
            status_detail=self.status_detail,
            type=self.type)


def get_flink_connection(compute_pool: Optional[Union['GetFlinkConnectionComputePoolArgs', 'GetFlinkConnectionComputePoolArgsDict']] = None,
                         credentials: Optional[Union['GetFlinkConnectionCredentialsArgs', 'GetFlinkConnectionCredentialsArgsDict']] = None,
                         display_name: Optional[_builtins.str] = None,
                         environment: Optional[Union['GetFlinkConnectionEnvironmentArgs', 'GetFlinkConnectionEnvironmentArgsDict']] = None,
                         organization: Optional[Union['GetFlinkConnectionOrganizationArgs', 'GetFlinkConnectionOrganizationArgsDict']] = None,
                         principal: Optional[Union['GetFlinkConnectionPrincipalArgs', 'GetFlinkConnectionPrincipalArgsDict']] = None,
                         rest_endpoint: Optional[_builtins.str] = None,
                         type: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFlinkConnectionResult:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `FlinkConnection` describes a Flink Connection data source.

    ## Example Usage


    :param _builtins.str display_name: The name of the Flink Connection.
    :param _builtins.str rest_endpoint: The REST endpoint of the Flink region, for example, `https://flink.us-east-1.aws.confluent.cloud`).
    :param _builtins.str type: The type of the Flink Connection. The accepted values are: `OPENAI`, `AZUREML`, `AZUREOPENAI`, `BEDROCK`, `SAGEMAKER`, `GOOGLEAI`, `VERTEXAI`, `MONGODB`, `PINECONE`, `ELASTIC` and `COUCHBASE`.
    """
    __args__ = dict()
    __args__['computePool'] = compute_pool
    __args__['credentials'] = credentials
    __args__['displayName'] = display_name
    __args__['environment'] = environment
    __args__['organization'] = organization
    __args__['principal'] = principal
    __args__['restEndpoint'] = rest_endpoint
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('confluentcloud:index/getFlinkConnection:getFlinkConnection', __args__, opts=opts, typ=GetFlinkConnectionResult).value

    return AwaitableGetFlinkConnectionResult(
        compute_pool=pulumi.get(__ret__, 'compute_pool'),
        credentials=pulumi.get(__ret__, 'credentials'),
        data=pulumi.get(__ret__, 'data'),
        display_name=pulumi.get(__ret__, 'display_name'),
        endpoint=pulumi.get(__ret__, 'endpoint'),
        environment=pulumi.get(__ret__, 'environment'),
        id=pulumi.get(__ret__, 'id'),
        organization=pulumi.get(__ret__, 'organization'),
        principal=pulumi.get(__ret__, 'principal'),
        rest_endpoint=pulumi.get(__ret__, 'rest_endpoint'),
        status=pulumi.get(__ret__, 'status'),
        status_detail=pulumi.get(__ret__, 'status_detail'),
        type=pulumi.get(__ret__, 'type'))
def get_flink_connection_output(compute_pool: Optional[pulumi.Input[Optional[Union['GetFlinkConnectionComputePoolArgs', 'GetFlinkConnectionComputePoolArgsDict']]]] = None,
                                credentials: Optional[pulumi.Input[Optional[Union['GetFlinkConnectionCredentialsArgs', 'GetFlinkConnectionCredentialsArgsDict']]]] = None,
                                display_name: Optional[pulumi.Input[_builtins.str]] = None,
                                environment: Optional[pulumi.Input[Optional[Union['GetFlinkConnectionEnvironmentArgs', 'GetFlinkConnectionEnvironmentArgsDict']]]] = None,
                                organization: Optional[pulumi.Input[Optional[Union['GetFlinkConnectionOrganizationArgs', 'GetFlinkConnectionOrganizationArgsDict']]]] = None,
                                principal: Optional[pulumi.Input[Optional[Union['GetFlinkConnectionPrincipalArgs', 'GetFlinkConnectionPrincipalArgsDict']]]] = None,
                                rest_endpoint: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFlinkConnectionResult]:
    """
    [![General Availability](https://img.shields.io/badge/Lifecycle%20Stage-General%20Availability-%2345c6e8)](https://docs.confluent.io/cloud/current/api.html#section/Versioning/API-Lifecycle-Policy)

    `FlinkConnection` describes a Flink Connection data source.

    ## Example Usage


    :param _builtins.str display_name: The name of the Flink Connection.
    :param _builtins.str rest_endpoint: The REST endpoint of the Flink region, for example, `https://flink.us-east-1.aws.confluent.cloud`).
    :param _builtins.str type: The type of the Flink Connection. The accepted values are: `OPENAI`, `AZUREML`, `AZUREOPENAI`, `BEDROCK`, `SAGEMAKER`, `GOOGLEAI`, `VERTEXAI`, `MONGODB`, `PINECONE`, `ELASTIC` and `COUCHBASE`.
    """
    __args__ = dict()
    __args__['computePool'] = compute_pool
    __args__['credentials'] = credentials
    __args__['displayName'] = display_name
    __args__['environment'] = environment
    __args__['organization'] = organization
    __args__['principal'] = principal
    __args__['restEndpoint'] = rest_endpoint
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('confluentcloud:index/getFlinkConnection:getFlinkConnection', __args__, opts=opts, typ=GetFlinkConnectionResult)
    return __ret__.apply(lambda __response__: GetFlinkConnectionResult(
        compute_pool=pulumi.get(__response__, 'compute_pool'),
        credentials=pulumi.get(__response__, 'credentials'),
        data=pulumi.get(__response__, 'data'),
        display_name=pulumi.get(__response__, 'display_name'),
        endpoint=pulumi.get(__response__, 'endpoint'),
        environment=pulumi.get(__response__, 'environment'),
        id=pulumi.get(__response__, 'id'),
        organization=pulumi.get(__response__, 'organization'),
        principal=pulumi.get(__response__, 'principal'),
        rest_endpoint=pulumi.get(__response__, 'rest_endpoint'),
        status=pulumi.get(__response__, 'status'),
        status_detail=pulumi.get(__response__, 'status_detail'),
        type=pulumi.get(__response__, 'type')))
